@@ -27,9 +27,9 @@ frozen/finalised. Names may change slightly or be added or removed.
 
 =head2 L<PPI::Statement::Scheduled>
 
-This covers all "scheduled" blocks, chunks of code that are executed
-separately from the main body of the code, at a particular time. This
-includes all C<BEGIN>, C<CHECK>, C<INIT> and C<END> blocks.
+This covers all "scheduled" blocks, chunks of code that are executed separately
+from the main body of the code, at a particular time. This includes all
+C<BEGIN>, C<CHECK>, C<UNITCHECK>, C<INIT> and C<END> blocks.
 
 =head2 L<PPI::Statement::Package>
 
@@ -50,7 +50,7 @@ A named subroutine declaration, or forward declaration
 A variable declaration statement. This could be either a straight
 declaration or also be an expression.
 
-This includes all 'my', 'local' and 'out' statements.
+This includes all 'my', 'state', 'local' and 'our' statements.
 
 =head2 L<PPI::Statement::Compound>
 
@@ -68,7 +68,17 @@ a ';' statement terminator.
 
 A statement that breaks out of a structure.
 
-This includes all of 'redo', 'next', 'last' and 'return' statements.
+This includes all of 'redo', 'goto', 'next', 'last' and 'return' statements.
+
+=head2 L<PPI::Statement::Given>
+
+The kind of statement introduced in Perl 5.10 that starts with 'given'.  This
+has an implicit end.
+
+=head2 L<PPI::Statement::When>
+
+The kind of statement introduced in Perl 5.10 that starts with 'when' or
+'default'.  This also has an implicit end.
 
 =head2 L<PPI::Statement::Data>
 
@@ -137,13 +147,15 @@ of the methods that are subclass-specific.
 =cut
 
 use strict;
-use base 'PPI::Node';
-use Params::Util                   '_INSTANCE';
+use Scalar::Util   ();
+use Params::Util   qw{_INSTANCE};
+use PPI::Node      ();
+use PPI::Exception ();
+use PPI::Singletons '%_PARENT';
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.272';
+
+our @ISA = "PPI::Node";
 
 use PPI::Statement::Break          ();
 use PPI::Statement::Compound       ();
@@ -155,14 +167,16 @@ use PPI::Statement::Null           ();
 use PPI::Statement::Package        ();
 use PPI::Statement::Scheduled      ();
 use PPI::Statement::Sub            ();
+use PPI::Statement::Given         ();
 use PPI::Statement::UnmatchedBrace ();
 use PPI::Statement::Unknown        ();
 use PPI::Statement::Variable       ();
+use PPI::Statement::When           ();
 
 # "Normal" statements end at a statement terminator ;
-# Some are not, and need the more rigorous _statement_continues to see
+# Some are not, and need the more rigorous _continues to see
 # if we are at an implicit statement boundary.
-sub __LEXER__normal { 1 }
+sub __LEXER__normal() { 1 }
 
 
 
@@ -172,16 +186,24 @@ sub __LEXER__normal { 1 }
 # Constructor
 
 sub new {
-	my $class = ref $_[0] ? ref shift : shift;
-	
+	my $class = shift;
+	if ( ref $class ) {
+		PPI::Exception->throw;
+	}
+
 	# Create the object
 	my $self = bless { 
 		children => [],
-		}, $class;
+	}, $class;
 
 	# If we have been passed what should be an initial token, add it
-	if ( _INSTANCE($_[0], 'PPI::Token') ) {
-		$self->__add_element(shift);
+	my $token = shift;
+	if ( _INSTANCE($token, 'PPI::Token') ) {
+		# Inlined $self->__add_element(shift);
+		Scalar::Util::weaken(
+			$_PARENT{Scalar::Util::refaddr $token} = $self
+		);
+		push @{$self->{children}}, $token;
 	}
 
 	$self;
@@ -213,6 +235,25 @@ sub label {
 
 =pod
 
+=head2 specialized
+
+Answer whether this is a plain statement or one that has more
+significance.
+
+Returns true if the statement is a subclass of this one, false
+otherwise.
+
+=cut
+
+# Yes, this is doing precisely what it's intending to prevent
+# client code from doing.  However, since it's here, if the
+# implementation changes, code outside PPI doesn't care.
+sub specialized {
+	__PACKAGE__ ne ref $_[0];
+}
+
+=pod
+
 =head2 stable
 
 Much like the L<PPI::Document> method of the same name, the ->stable
@@ -226,7 +267,6 @@ error.
 =cut
 
 sub stable {
-	my $self = shift;
 	die "The ->stable method has not yet been implemented";	
 }
 
@@ -243,7 +283,7 @@ sub _complete {
 	my $self = shift;
 	my $semi = $self->schild(-1);
 	return !! (
-		$semi
+		defined $semi
 		and
 		$semi->isa('PPI::Token::Structure')
 		and
@@ -251,7 +291,7 @@ sub _complete {
 	);
 }
 
-# You can insert either a statement, or a non-significant token.
+# You can insert either a statement or a non-significant token.
 sub insert_before {
 	my $self    = shift;
 	my $Element = _INSTANCE(shift, 'PPI::Element') or return undef;
@@ -275,25 +315,6 @@ sub insert_after {
 	'';
 }
 
-
-
-
-
-#####################################################################
-# Support Methods
-
-sub _Fragment {
-	my $self = shift;
-
-	# Because we are potentially part of a larger structure,
-	# we need to clone ourselves first.
-	my $clone = $self->clone or return undef;
-
-	# Create the empty Fragment
-	my $Fragment = PPI::Document::Fragment->new;
-	$Fragment->add_element( $self ) or return undef;
-}
-
 1;
 
 =pod
@@ -312,7 +333,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
