@@ -17,13 +17,13 @@ PPI::Token::Magic - Tokens representing magic variables
 
   # When we say magic variables, we mean these...
   $1   $2   $3   $4   $5   $6   $7   $8   $9
-  $_   $&   $`   $'   $+   @+   $*   $.   $/    $|
-  $\\  $"   $;   $%   $=   $-   @-   $)   $#
+  $_   $&   $`   $'   $+   @+   %+   $*   $.    $/    $|
+  $\   $"   $;   $%   $=   $-   @-   %-   $)    $#
   $~   $^   $:   $?   $!   %!   $@   $$   $<    $>
   $(   $0   $[   $]   @_   @*   $}   $,   $#+   $#-
   $^L  $^A  $^E  $^C  $^D  $^F  $^H
   $^I  $^M  $^N  $^O  $^P  $^R  $^S
-  $^T  $^V  $^W  $^X
+  $^T  $^V  $^W  $^X  %^H
 
 =head1 DESCRIPTION
 
@@ -36,52 +36,37 @@ probably never encounter in your Perl career.
 
 =head1 METHODS
 
-The class provides no additional methods, beyond those provided by it's
+The class provides no additional methods, beyond those provided by
 L<PPI::Token::Symbol>, L<PPI::Token> and L<PPI::Element>.
 
 =cut
 
 use strict;
-use base 'PPI::Token::Symbol';
+use PPI::Token::Symbol ();
+use PPI::Token::Unknown ();
+use PPI::Singletons qw' %MAGIC $CURLY_SYMBOL ';
 
-use vars qw{$VERSION %magic};
-BEGIN {
-	$VERSION = '1.115';
+our $VERSION = '1.272';
 
-	# Magic variables taken from perlvar.
-	# Several things added separately to avoid warnings.
-	foreach ( qw{
-		$1 $2 $3 $4 $5 $6 $7 $8 $9
-		$_ $& $` $' $+ @+ $* $. $/ $|
-		$\\ $" $; $% $= $- @- $)
-		$~ $^ $: $? $! %! $@ $$ $< $>
-		$( $0 $[ $] @_ @*
-
-		$^L $^A $^E $^C $^D $^F $^H
-		$^I $^M $^N $^O $^P $^R $^S
-		$^T $^V $^W $^X
-
-		$::|
-	}, '$}', '$,', '$#', '$#+', '$#-' ) {
-		$magic{$_} = 1;
-	}
-}
+our @ISA = "PPI::Token::Symbol";
 
 sub __TOKENIZER__on_char {
 	my $t = $_[1];
-	$_ = $t->{token}->{content} . substr( $t->{line}, $t->{line_cursor}, 1 );
+
+	# $c is the candidate new content
+	my $c = $t->{token}->{content} . substr( $t->{line}, $t->{line_cursor}, 1 );
 
 	# Do a quick first test so we don't have to do more than this one.
 	# All of the tests below match this one, so it should provide a
 	# small speed up. This regex should be updated to match the inside
 	# tests if they are changed.
-	if ( /^  \$  .*  [  \w  :  \$  \{  ]  $/x ) {
+	if ( $c =~ /^  \$  .*  [  \w  :  \$  \{  ]  $/x ) {
 
-		if ( /^(\$(?:\_[\w:]|::))/ or /^\$\'[\w]/ ) {
+		if ( $c =~ /^(\$(?:\_[\w:]|::))/ or $c =~ /^\$\'[\w]/ ) {
 			# If and only if we have $'\d, it is not a
-			# symbol. (this was apparently a concious choice)
+			# symbol. (this was apparently a conscious choice)
 			# Note that $::0 on the other hand is legal
-			if ( /^\$\'\d$/ ) {
+			if ( $c =~ /^\$\'\d$/ ) {
 				# In this case, we have a magic plus a digit.
 				# Save the CURRENT token, and rerun the on_char
 				return $t->_finalize_token->__TOKENIZER__on_char( $t );
@@ -89,48 +74,97 @@ sub __TOKENIZER__on_char {
 
 			# A symbol in the style $_foo or $::foo or $'foo.
 			# Overwrite the current token
-			$t->_set_token_class('Symbol');
+			$t->{class} = $t->{token}->set_class('Symbol');
 			return PPI::Token::Symbol->__TOKENIZER__on_char( $t );
 		}
 
-		if ( /^\$\$\w/ ) {
+		if ( $c =~ /^\$\$\w/ ) {
 			# This is really a scalar dereference. ( $$foo )
 			# Add the current token as the cast...
 			$t->{token} = PPI::Token::Cast->new( '$' );
 			$t->_finalize_token;
 
 			# ... and create a new token for the symbol
-			$t->_new_token( 'Symbol', '$' ) or return undef;
-			return 1;
+			return $t->_new_token( 'Symbol', '$' );
 		}
 
-		if ( $_ eq '$#$' or $_ eq '$#{' ) {
+		if ( $c eq '$${' ) {
+			# This _might_ be a dereference of one of the
+			# control-character symbols.
+			pos $t->{line} = $t->{line_cursor} + 1;
+			if ( $t->{line} =~ m/$CURLY_SYMBOL/gc ) {
+				# This is really a dereference. ( $${^_foo} )
+				# Add the current token as the cast...
+				$t->{token} = PPI::Token::Cast->new( '$' );
+				$t->_finalize_token;
+
+				# ... and create a new token for the symbol
+				return $t->_new_token( 'Magic', '$' );
+			}
+		}
+
+		if ( $c eq '$#$' or $c eq '$#{' ) {
 			# This is really an index dereferencing cast, although
 			# it has the same two chars as the magic variable $#.
-			$t->_set_token_class('Cast');
+			$t->{class} = $t->{token}->set_class('Cast');
 			return $t->_finalize_token->__TOKENIZER__on_char( $t );
 		}
 
-		if ( /^(\$\#)\w/ ) {
+		if ( $c =~ /^(\$\#)\w/ ) {
 			# This is really an array index thingy ( $#array )
-			$t->{token} = PPI::Token::ArrayIndex->new( $1 );
+			$t->{token} = PPI::Token::ArrayIndex->new( "$1" );
 			return PPI::Token::ArrayIndex->__TOKENIZER__on_char( $t );
 		}
 
-		if ( /^\$\^\w/o ) {
+		if ( $c =~ /^\$\^\w+$/o ) {
 			# It's an escaped char magic... maybe ( like $^M )
-			return 1;
+			my $next = substr( $t->{line}, $t->{line_cursor}+1, 1 ); # Peek ahead
+			if ($MAGIC{$c} && (!$next || $next !~ /\w/)) {
+				$t->{token}->{content} = $c;
+				$t->{line_cursor}++;
+			} else {
+				# Maybe it's a long magic variable like $^WIDE_SYSTEM_CALLS
+				return 1;
+			}
 		}
 
-		if ( /^\$\#\{/ ) {
-			# The $# is actually a case, and { is its block
+		if ( $c =~ /^\$\#\{/ ) {
+			# The $# is actually a cast, and { is its block
 			# Add the current token as the cast...
 			$t->{token} = PPI::Token::Cast->new( '$#' );
 			$t->_finalize_token;
 
 			# ... and create a new token for the block
-			$t->_new_token( 'Structure', '{' ) or return undef;
-			return 1;
+			return $t->_new_token( 'Structure', '{' );
+		}
+	} elsif ($c =~ /^%\^/) {
+		return 1 if $c eq '%^';
+		# It's an escaped char magic... maybe ( like %^H )
+		if ($MAGIC{$c}) {
+			$t->{token}->{content} = $c;
+			$t->{line_cursor}++;
+		} else {
+			# Back off, treat '%' as an operator
+			chop $t->{token}->{content};
+			bless $t->{token}, $t->{class} = 'PPI::Token::Operator';
+			$t->{line_cursor}--;
+		}
+	}
+
+	if ( $MAGIC{$c} ) {
+		# $#+ and $#-
+		$t->{line_cursor} += length( $c ) - length( $t->{token}->{content} );
+		$t->{token}->{content} = $c;
+	} else {
+		pos $t->{line} = $t->{line_cursor};
+		if ( $t->{line} =~ m/($CURLY_SYMBOL)/gc ) {
+			# control character symbol (e.g. ${^MATCH})
+			$t->{token}->{content} .= $1;
+			$t->{line_cursor}      += length $1;
+		} elsif ( $c =~ /^\$\d+$/ and $t->{line} =~ /\G(\d+)/gc ) {
+			# Grab trailing digits of regex capture variables.
+			$t->{token}{content} .= $1;
+			$t->{line_cursor} += length $1;
 		}
 	}
 
@@ -147,15 +181,15 @@ sub canonical { $_[0]->content }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
